//
//  WordNetManager.h
//  WNShell3
//
//  Created by hogwood on Fri Apr 12 2002.
//  Copyright (c) 2002 Tinc. All rights reserved.
//

#import <Foundation/Foundation.h>

#define NUM_KIND_RELATIONS 16
#define NUMBER_OF_DICT_FILES_FOR_TYPE 4

typedef enum {words, antonyms, hypernyms, hyponyms, holonyms, meronyms, attributes,
              entailments, causes, seealso, verbgroup, 
              similarities, participles, pertainyms,
              frames, gloss} Relation;

typedef enum {noun = 1, verb, adj, adv} POS;

@interface WordNetManager : NSObject {
    NSBundle* _dataBundle;
    NSMutableDictionary *_indexDict, *_dataDict;
    NSArray *_nounRoots, *_verbRoots;
    FILE *indexFiles[NUMBER_OF_DICT_FILES_FOR_TYPE + 1];
    FILE *dataFiles[NUMBER_OF_DICT_FILES_FOR_TYPE + 1];
    FILE *excFiles[NUMBER_OF_DICT_FILES_FOR_TYPE + 1];
}

+ (WordNetManager*) defaultManager ;

- (id)initWithBundle:(NSBundle *)bundle;
- (NSBundle *)dataBundle;

- (NSArray *)dataForSynset:(NSNumber *)synset;
- (id)dataForSynset:(NSNumber *)synset withRelation:(Relation)r;

- (NSArray *)wordsForSynset:(NSNumber *)synset;
- (NSArray *)synsetsForWord:(NSString *)word;
- (NSArray *)synsetsForInflectedWord:(NSString *)word;
- (NSNumber*) randomSynset ;

- (POS)posForSynset:(NSNumber *)synset;
- (NSString *)avatarForSynset:(NSNumber *)synset;
- (NSString *)avatarForSynset:(NSNumber *)synset withConstraint:(NSString *)word;
- (NSString *)synsetPrefix:(NSNumber *)synset toAvatar:(NSString *)avatar;
- (NSString *)posPrefixForSynset:(NSNumber *)synset;
- (NSString *)posPrefixForSynset:(NSNumber *)synset toAvatar:(NSString *)avatar;
- (NSString *)dropPrefixForAvatar:(NSString *)avatar;

- (NSString *)glossForSynset:(NSNumber *)synset;

- (NSArray *)allHypernymRoots;
- (NSArray *)hypernymNounRoots;
- (NSArray *)hypernymVerbRoots;

- (NSNumber *)hypernymForSynset:(NSNumber *)synset;
- (NSArray *)hyponymsForSynset:(NSNumber *)synset;
- (NSArray *)multipleHypernymsForSynset:(NSNumber *)synset;
- (NSArray *)ancestryForSynset:(NSNumber *)synset;
- (NSNumber*) parentForSynset:(NSNumber*)synset ;

- (NSArray *)similaritiesToSynset:(NSNumber *)synset;
- (NSArray *)antonymsForSynset:(NSNumber *)synset;

- (NSArray *)framesForSynset:(NSNumber *)synset;

- (NSArray *)meronymsForSynset:(NSNumber *)synset;
- (NSArray *)holonymsForSynset:(NSNumber *)synset;

- (NSArray *)causesForSynset:(NSNumber *)synset;
- (NSArray *)entailmentsForSynset:(NSNumber *)synset;

- (NSArray *)seeAlsoForSynset:(NSNumber *)synset;
- (NSArray *)verbGroupForSynset:(NSNumber *)synset;
- (NSArray *)attributesForSynset:(NSNumber *)synset;

- (NSArray *)participlesForSynset:(NSNumber *)synset;
- (NSArray *)pertainymsForSynset:(NSNumber *)synset;

@end
